/// <reference path="jquery.js" />
/// <reference path="jquery.mCustomScrollbar.concat.min.js" />
/// <reference path="../cordova.js" />
/// <reference path="pushnotification.js" />


/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
var app = {
    // Application Constructor
    initialize: function () {
        this.bindEvents();
    },
    // Bind Event Listeners
    //
    // Bind any events that are required on startup. Common events are:
    // `load`, `deviceready`, `offline`, and `online`.
    bindEvents: function () {
        document.addEventListener('deviceready', this.onDeviceReady, false);
    },
    // deviceready Event Handler
    //
    // The scope of `this` is the event. In order to call the `receivedEvent`
    // function, we must explicity call `app.receivedEvent(...);`
    onDeviceReady: function () {
        app.receivedEvent('deviceready');
        $().initializeApp();
    },
    // Update DOM on a Received Event
    receivedEvent: function (id) {
        var parentElement = document.getElementById(id);
        var listeningElement = parentElement.querySelector('.listening');
        var receivedElement = parentElement.querySelector('.received');

        listeningElement.setAttribute('style', 'display:none;');
        receivedElement.setAttribute('style', 'display:block;');
    }
};

(function ($) {

    var pushNotification;
    var currentPage = 0;
    var dbShell = null;
    var shops = [];
    var currentLatitude;
    var currentLongitude;
    var currentShop;
    var history = [];
    var allshops = []; // magasins tris pour optimiser la vitesse d'affichage
    var subshops = [];
    var shipments = null;
    var ios_token;
    var android_token;
    var refreshing = false;
    var resizeInterval;
    var mode = "nearest";

    /**
    * Gestion des liens externes
    **/
    $(document).on('tap click', 'a[target="_blank"], area[target="_blank"]', function (e) {
        e.preventDefault();
        var inbrowser = window.open(this.href, '_blank', 'location=yes');
        inbrowser.addEventListener("exit", function () {
            document.location.refresh();
        });
    });

    $(document).on('tap click', '#gpslink', function (e) {
        e.preventDefault();
        window.open(this.href, '_system', 'location=yes');
    });

    /**
    * Autocompltion sur la ville dans le formaulaire de recherche d'un magasin
    **/
    $("#searchInput").on("input paste propertychange", function (e) {

        mode = "search";

        // on rcupre le texte tap et on le passe en minuscule
        var text = $(this).val().toLowerCase().replace(/ /g, '').replace(/-/g, '');


        // on filtre les magsins ayant un nom commencant par ce texte tap
        var todisplay = allshops.filter(function (shop) {
            var city = (shop.City || "").toLowerCase().replace(/ /g, '').replace(/-/g, '');
            var postalCode = shop.PostalCode;
            return city.startsWith(text) || postalCode.startsWith(text);
        });

        var alpha = todisplay.sort(function (a, b) {

            var aname = (isNullOrEmpty(a.City) ? a.Name : a.City).toLowerCase();
            var bname = (isNullOrEmpty(b.City) ? b.Name : b.City).toLowerCase();
            return aname < bname ? -1 : (aname > bname ? 1 : 0);
        });

        alpha = alpha.slice(0, alpha.length);

        displayFoundShops(alpha);

    });

    $("#searchInput").on("blur closeKeyboard", function (e) {
        var win = $("#magfound .results>div>div");
        var winpos = win.closest(".results").position().top;

        var height = win.closest(".page").find(".footer").position().top - winpos - 12;
        win.css("height", height + "px");

        ul.closest(".winfound").mCustomScrollbar("update");
    });

    /**
    * Autocompltion sur la ville dans le formulaire d'ajout d'un magasin en favori
    **/
    $(document).on("input paste", "#addmag input[name='searchbox']", function (e) {

        // on rcupre le texte tap et on le passe en minuscule
        var text = $(this).val().toLowerCase().replace(String.fromCharCode(233), 'e');


        // on filtre les magsins ayant un nom commencant par ce texte tap
        var todisplay = allshops.filter(function (shop) {
            var city = (shop.City || "").toLowerCase().replace(String.fromCharCode(233), 'e');
            var postalCode = shop.PostalCode;
            return city.startsWith(text) || postalCode.startsWith(text);
        });

        todisplay.sort(function (a, b) {

            var aname = (isNullOrEmpty(a.City) ? a.Name : a.City).toLowerCase().replace(String.fromCharCode(233), 'e');
            var bname = (isNullOrEmpty(b.City) ? b.Name : b.City).toLowerCase().replace(String.fromCharCode(233), 'e');

            return (aname < bname) ? -1 : (aname > bname ? 1 : 0);
        });

        var alpha = todisplay.slice(0, todisplay.length);

        displayShopsList(alpha);

    });

    /**
    * Gestion des boutons amenant sur d'autres pages
    **/
    $(document).on("tap click", ".load-page", function (e) {

        e.preventDefault();

        $.fn.loadpage($(this).attr("data-page"));
    });


    /**
    * Recherche de tous les magasins
    **/
    $(document).on("tap click", "#allmag", function (e) {
        e.preventDefault();
        mode = "all";
        displayAllShops();
    });

    $("#allmagimg").bind("click", function (e) {
        e.preventDefault();
        mode = "all";
        displayAllShops();
    });

    $("#allmagimg").bind("touchstart", function (e) {
        $(this).attr("src", "img/PICTO_liste_click.png");
    });

    $("#allmagimg").bind("touchend", function (e) {
        $(this).attr("src", "img/NOZ_liste.png");
    });

    $("#allmagimg").hover(
        function (e) {
            $(this).attr("src", "img/PICTO_liste_click.png");
        },
        function (e) {
            $(this).attr("src", "img/NOZ_liste.png");
        });


    $(".add").bind("touchstart", function (e) {
        $(this).attr("src", "img/PICTO_ajouter_click.png");
    });

    $(".add").bind("touchend", function (e) {
        $(this).attr("src", "img/NOZ_add.png");
    });

    $(".add").hover(
        function (e) {
            $(this).attr("src", "img/PICTO_ajouter_click.png");
        },
        function (e) {
            $(this).attr("src", "img/NOZ_add.png");
        });


    //$(document).on("touchstart", ".item a.addtofavorite", function (e) {
    //    $(this).find("img").attr("src", "img/PICTO_ajouter_click.png");
    //});

    //$(document).on("touchend", ".item a.addtofavorite", function (e) {
    //    $(this).find("img").attr("src", "img/NOZ_add.png");
    //});

    //$(document).on("mouseover", ".item a.addtofavorite",
    //    function (e) {
    //        $(this).find("img").attr("src", "img/PICTO_ajouter_click.png");
    //    });

    //$(document).on("mouseleave", ".item a.addtofavorite",
    //    function (e) {
    //        $(this).find("img").attr("src", "img/NOZ_add.png");
    //    });

    $(document).on("touchstart", ".magfound .window .item", function (e) {
        $(this).css("background-color", "#9393C0");
    });

    $(document).on("touchend", ".magfound .window .item", function (e) {
        $(this).css("background-color", "#bec0da");
    });

    $(document).on("touchstart", ".fivemag .myshops-list li", function (e) {
        $(this).css("background-color", "#9393C0");
    });

    $(document).on("touchend", ".fivemag .myshops-list li", function (e) {
        $(this).css("background-color", "#bec0da");
        removeFavorite($(this).data("shop"));
        $.fn.loadpage(currentPage, true);
    });

    /**
    * Recherche des magasins les plus proches
    **/
    $(document).on("tap click", "#proxi", function (e) {
        e.preventDefault();
        displayNearestShops();
    });

    $("#proxyimg").bind("click", function (e) {
        e.preventDefault();
        displayNearestShops();
    });

    $("#proxyimg").bind("touchstart", function (e) {
        $(this).attr("src", "img/PICTO_cible_click.png");
    });

    $("#proxyimg").bind("touchend", function (e) {
        $(this).attr("src", "img/NOZ_geolocalisation.png");
    });

    $("#proxyimg").hover(
        function (e) {
            $(this).attr("src", "img/PICTO_cible_click.png");
        },
        function (e) {
            $(this).attr("src", "img/NOZ_geolocalisation.png");
        });

    $("#searchimg").bind("click", function (e) {
        e.preventDefault();
        $("#searchInput").focus();
    });


    $("#searchimg").bind("touchstart", function (e) {
        $(this).attr("src", "img/PICTO_loupe_click.png");
    });

    $("#searchimg").bind("touchend", function (e) {
        $(this).attr("src", "img/NOZ_loupe.png");
    });

    $("#searchimg").hover(
        function (e) {
            $(this).attr("src", "img/PICTO_loupe_click.png");
        },
        function (e) {
            $(this).attr("src", "img/NOZ_loupe.png");
        });

    $("#parametres>a>img").bind("touchstart", function (e) {
        $(this).attr("src", "img/PICTO_param_rond_click.png");
    });

    $("#parametres>a>img").bind("touchend", function (e) {
        $(this).attr("src", "img/NOZ_parametres.png");
    });

    $("#parametres>a>img").hover(
        function (e) {
            $(this).attr("src", "img/PICTO_param_rond_click.png");
        },
        function (e) {
            $(this).attr("src", "img/NOZ_parametres.png");
        });

    $("#gpslink>img").bind("touchstart", function (e) {
        $(this).attr("src", "img/NOZ_geomag_click.png");
    });

    $("#gpslink>img").bind("touchend", function (e) {
        $(this).attr("src", "img/NOZ_geomag.png");
    });

    $("#recrute>a>img").bind("touchstart", function (e) {
        $(this).attr("src", "img/NOZ_recrute_click.png");
    });

    $("#recrute>a>img").bind("touchend", function (e) {
        $(this).attr("src", "img/NOZ_recrute.png");
    });

    $("#connect img.para").bind("touchstart", function (e) {
        $(this).attr("src", "img/PICTO_param_orange_click.png");
    });

    $("#connect img.para").bind("touchend", function (e) {
        $(this).attr("src", "img/NOZ_parametres_page.png");
    });

    $("#connect img.para").hover(
           function (e) {
               $(this).attr("src", "img/PICTO_param_orange_click.png");
           },
           function (e) {
               $(this).attr("src", "img/NOZ_parametres_page.png");
           });


    $(".footer .bar a[data-page=1] img").bind("touchstart", function (e) {
        $(this).attr("src", "img/PICTO_home_click.png");
    });

    $(".footer .bar a[data-page=1] img").bind("touchend", function (e) {
        $(this).attr("src", "img/NOZ_home.png");
    });

    $(".footer .bar a[data-page=1] img").hover(
           function (e) {
               $(this).attr("src", "img/PICTO_home_click.png");
           },
           function (e) {
               $(this).attr("src", "img/NOZ_home.png");
           });


    $(".footer .bar a.retour img").bind("touchstart", function (e) {
        $(this).attr("src", "img/PICTO_retour_click.png");
    });

    $(".footer .bar a.retour img").bind("touchend", function (e) {
        $(this).attr("src", "img/NOZ_retour.png");
    });

    $(".footer .bar a.retour img").hover(
           function (e) {
               $(this).attr("src", "img/PICTO_retour_click.png");
           },
           function (e) {
               $(this).attr("src", "img/NOZ_retour.png");
           });


    $(".footer .bar a.addtofavorite img").bind("touchstart", function (e) {
        $(this).attr("src", "img/PICTO_favoris_click.png");
    });

    $(".footer .bar a.addtofavorite img").bind("touchend", function (e) {
        $(this).attr("src", "img/NOZ_like.png");
    });

    $(".footer .bar a.addtofavorite img").hover(
           function (e) {
               $(this).attr("src", "img/PICTO_favoris_click.png");
           },
           function (e) {
               $(this).attr("src", "img/NOZ_like.png");
           });


    $(".shopmap-link img").bind("touchstart", function (e) {
        $(this).attr("src", "img/NOZ_me-rendre-dans-ce-magasin_click.png");
    });

    $(".shopmap-link img").bind("touchend", function (e) {
        $(this).attr("src", "img/NOZ_me-rendre-dans-ce-magasin.png");
    });

    $(".shopmap-link img").hover(
           function (e) {
               $(this).attr("src", "img/NOZ_me-rendre-dans-ce-magasin_click.png");
           },
           function (e) {
               $(this).attr("src", "img/NOZ_me-rendre-dans-ce-magasin.png");
           });

    $("#callto a[data-page=6] img").bind("touchstart", function (e) {
        $(this).attr("src", "img/NOZ_voir-les-arrivages-de-la-semaine_click.png");
    });

    $("#callto a[data-page=6] img").bind("touchend", function (e) {
        $(this).attr("src", "img/NOZ_voir-les-arrivages-de-la-semaine.png");
    });

    $("#callto a[data-page=6] img").hover(
           function (e) {
               $(this).attr("src", "img/NOZ_voir-les-arrivages-de-la-semaine_click.png");
           },
           function (e) {
               $(this).attr("src", "img/NOZ_voir-les-arrivages-de-la-semaine.png");
           });

    /**
    * Activation ou dsactivation du psuh
    */
    $(document).on("change", "#pushbtn", function (e) {
        e.preventDefault();

        var params = getParameters();
        params.notif = this.checked;
        setParameters(params);
        updatePush();

    });


    var updatePush = function () {

        setTimeout(function () {
            var params = getParameters();
            var shopIds = "";

            $(params.myShops).each(function () {
                shopIds += this.Id + ";";
            });

            if (device.platform == "iPhone" || device.platform == "iOS") {

                var pushNotification = window.plugins.pushNotification;

                $(".event.received").html(params.ios_token);

                pushNotification.register(function (result) {
                    ios_token = result;
                    if (params.notif) {
                        $.ajax({
                            url: 'http://nozappliv2.azurewebsites.net/api/notification',
                            type: 'POST',
                            crossDomain: true,
                            dataType: 'json',
                            contentType: 'application/json;charset=utf-8',
                            data: JSON.stringify({
                                platform: 'ios',
                                deviceToken: ios_token,
                                shopIds: shopIds,
                                unsuscribed: false,
                                instId: 'ios' + result
                            })
                        });
                    }
                    else if (params.ios_token) {
                        $.ajax({
                            url: 'http://nozappliv2.azurewebsites.net/api/notification',
                            type: 'POST',
                            crossDomain: true,
                            dataType: 'json',
                            contentType: 'application/json;charset=utf-8',
                            data: JSON.stringify({
                                platform: 'ios',
                                deviceToken: ios_token,
                                unsuscribed: true,
                                instId: 'ios' + ios_token
                            })
                        });
                    }

                    params.ios_token = ios_token;
                    setParameters(params);

                },
                function (error) {
                    document.getElementById("pushbtn").checked = false;
                    $(".event.received").html("error " + error);
                },
                {
                    badge: true,
                    sound: false,
                    alert: true
                });
            }
            else if (device.platform == 'android' || device.platform == 'Android') {

                var pushNotification = window.plugins.pushNotification;

                $(".event.received").html("update push ");

                pushNotification.register(
                    function (result) {

                        $(".event.received").html("token: " + result);

                        android_token = result;

                    },
                     function (error) {
                         document.getElementById("pushbtn").checked = false;
                         $(".event.received").html("error " + error);
                     },
                    {
                        "senderID": "761340963558",
                        "ecb": "onNotificationGCM"
                    });

            }
        }, 1000);

    }

    /**
    * Ajout d'un magasin en favori 
    **/
    $(document).on("tap click", ".addtofavorite", function (e) {
        e.preventDefault();


        var shop = $(this).data("shop");
        addFavoriteShop(shop);

        if (currentPage != 6) {
            setTimeout(function () {
                $.fn.loadpage(3);
            }, 500);
        } else {
            $("#city-added").html(isNullOrEmpty(shop.City) ? shop.Name : shop.City)
            $("#over").show();
        }
    });

    var refreshShopData = function () {
        refreshData(function (data) {

            if (data.length === 0) {
                setTimeout(function () {
                    refreshShopData();
                }, 10000);
            }

            allshops = shops.slice(0, shops.length).sort(function (a, b) {

                var postal1 = (isNullOrEmpty(a.PostalCode) ? "99999" : a.PostalCode).substr(0, 2);
                var postal2 = (isNullOrEmpty(b.PostalCode) ? "99999" : b.PostalCode).substr(0, 2);

                if (postal1 > postal2) {
                    return 1;
                }

                if (postal1 < postal2) {
                    return -1;
                }

                return (isNullOrEmpty(a.City) ? a.Name : a.City) >= (isNullOrEmpty(b.City) ? b.Name : b.City) ? 1 : -1;
            });

            if (currentPage === 7) {
                $(document).loadpage(7, true);
            }
            else if (currentPage === 4) {
                $(document).loadpage(4, true);
            }
        });
    };

    /**
    * Initialisation de l'applicaton
    **/
    $.fn.initializeApp = function () {

        $(".event.received").html("initialization for " + device.platform);


        document.addEventListener("online", function () {
            refreshShopData();
        }, false);

        var parameters = getParameters();

        if (device.platform == "iPhone" || device.platform == "iOS") {
            // gestion de la barre de notif
        }

        $(".winfound").mCustomScrollbar();
        $('#pushbtn').switchButton({
            checked: (getParameters().notif === true)
        });

        setTimeout(function () {

            refreshShopData();

            loadScript();



            //refreshLocation();

        }, 500);

        setInterval(
        function refreshLocation() {
            var options = { timeout: 31000, enableHighAccuracy: true, maximumAge: 90000 };
            navigator.geolocation.getCurrentPosition(function (position) {

                var refreshAfter = true;

                if (currentLatitude) {
                    refreshAfter = false;
                }

                currentLatitude = position.coords.latitude;
                currentLongitude = position.coords.longitude;

                if (refreshAfter) {
                    $().loadpage(currentPage, false, false);
                }
            }, function (message) {
                setTimeout(function () {
                    refreshLocation();
                }, 2000);
            }, options);
        }, 1000);

        function loadScript() {
            var script = document.createElement('script');
            script.type = 'text/javascript';
            script.src = 'https://maps.googleapis.com/maps/api/js?v=3.exp&sensor=false&callback=googleMapsInit';
            document.body.appendChild(script);
        }

        $(document).loadpage(1, true);



    }

    /**
    * Chargement d'une page
    **/
    $.fn.loadpage = function (pageNumber, direct, isbackaction) {

        if ((!isbackaction) && (currentPage != 0) && (currentPage != pageNumber)) {

            if (history.length == 0) {
                document.addEventListener("backbutton", onBackButton, false);
            }

            history.push(currentPage);
        }

        $(".page[data-index='" + currentPage + "']").hide();

        var current = $(".page[data-index='" + pageNumber + "']");

        current.show();

        currentPage = pageNumber;

        $(".mCSB_container").css("top", 0);

        if (!isbackaction) {

            if (resizeInterval) {
                resizeInterval.clear();
            }

            if (current.attr("name") == "shopList") {
                displayNearestShops(current);
            }
            else if (current.attr("name") == "details") {
                displayShopDetails(current);
            }
            else if (current.attr("name") == "search") {
                subshops = shops.slice(0, shops.length);
                $("input[name = 'searchbox']").val("");

                var targetWidth = current.find(".window").width();
                $("input[name = 'searchbox']").css("width", targetWidth + "px");
                mode = "nearest";
                displayNearestShops(current);
            }
            else if (current.attr("name") == "geomag") {
                displayShopLocalisation(current);
            }
            else if (current.attr("name") == "allshops") {
                displayAllShops();
            }
            else if (current.attr("name") == "shipments") {
                displayShopShipments(current);
            }
            else if (current.attr("name") == "parameters") {
                displayParameters(current);
            }
            else if (current.attr("name") == "addshop") {
                displayAddShopList(current);
            }
            else if (current.attr("name") == "favorites") {
                displayFavoriteShopList(current);
            }
            else if (current.attr("name") == "home") {

                var left = $("#parametres img").position().left;
                var screenWidth = current.width();

                var screenHeight = current.height();
                var topBarHeight = current.find("#tophome").outerHeight();
                var bottomBarHeight = $("#parametres img").position().top;
                var displayHeight = screenHeight - topBarHeight - (screenHeight - bottomBarHeight);

                var width = Math.min(screenWidth - left * 2, displayHeight);

                var wheelHeight = $("#wheel").height();
                var marginTop = (displayHeight - wheelHeight) / 2 + "px";

                $("#wheel").css("margin-top", marginTop);
            }
            else if (current.attr("name") == "empty") {
                var param = getParameters();
                param.configured = true;
                setParameters(param);

                history.pop();
                history.push(1);
            }
        }
        else {
            if (current.attr("name") == "parameters") {
                displayParameters(current);
            }
            else if (current.attr("name") == "favorites") {
                displayFavoriteShopList(current);
            }
            else if (current.attr("name") == "search") {                
                if(mode == "nearest"){
                    displayNearestShops(current);
                }
            }
        }
    }

    /**
    * Gestion des boutons retours en bas de page
    **/
    $(document).on("tap click", ".retour", function (e) {
        e.preventDefault();
        onBackButton();
    });

    /**
    * Gestion du bouton prcdent
    **/
    var onBackButton = function () {

        var prevpage = history.pop();

        // Si pas d'historique, on renvoie sur l'application prcdente
        if (history.length === 0) {
            document.removeEventListener("backbutton", onBackButton, false);
        }

        $().loadpage(prevpage, true, true);
    }

    /**
    * Tlchargement des donnes magasins
    **/
    var refreshData = function (success) {

        if (refreshing === false) {
            refreshing = true;
            $.ajax({
                crossDomain: true,
                type: 'GET',
                url: 'http://nozappliv2.azurewebsites.net/api/shop',
                dataType: 'json',
                success: function (data) {
                    refreshing = false;
                    shops = data;
                    window.localStorage.setItem("shops", JSON.stringify(data));
                    success(shops);
                },
                error: function () {
                    refreshing = false;
                    // s'il y a une erreur on charge les donnes depuis la base
                    shops = JSON.parse(window.localStorage.getItem("shops"));

                    if (shops === null) {
                        shops = [];
                    }

                    success(shops);
                }
            });
        }
    }

    /**
    * Gestion de la page de paramtres 
    **/
    var displayParameters = function (current) {
        var param = getParameters();

        document.getElementById("pushbtn").checked = (param.notif === true);

        var ul = current.find(".myshops-list");
        ul.empty();

        var myshops = param.myShops;

        var hasShop = false;

        for (var index = 0; index < myshops.length; index++) {
            hasShop = true;
            var myshop = myshops[index];
            if (myshop != null) {
                var li = $("<li class='item'></li>");
                li.append("<h4>" + (isNullOrEmpty(myshop.City) ? myshop.Name : myshop.City) + "</h4");
                li.append("<p>" + myshop.Address + "</p>");
                li.append("<a href='#' class='remove-shop'> <img src='img/NOZ_erase.png'></a>");
                li.data("shop", myshop);

                li.click(function (e) {
                    e.preventDefault();
                    //removeFavorite($(this).data("shop"));
                    $.fn.loadpage(currentPage, true);
                });

                ul.append(li);
            }
        }

        if ($(ul).children().length === 0) {
            ul.append("<li class='empty-item'>Votre liste de magasins favoris est vide !</li>");
        }

        if ($(ul).children().length > 3) {
            current.find(".infos").hide();
        } else {
            current.find(".infos").show();
        }

        param.configured = true;


        if ($(ul).children().length < 5) {
            $("#add").show();
            current.find(".retour").show();

        } else {
            $("#add").hide();
            WinConsole.log(history);
            if (history[history.length - 1] == 4) {
                current.find(".retour").hide();
            } else {
                current.find(".retour").show();
            }

        }


        setParameters(param);
    }

    /**
    * Fiche d'un magsin
    **/
    var displayShopDetails = function (current) {


        shipments = null;

        $.ajax({
            crossDomain: true,
            type: 'GET',
            url: 'http://nozappliv2.azurewebsites.net/api/shipment?shopid=' + currentShop.Id,
            dataType: 'json',
            success: function (data) {
                shipments = data;
                if (currentPage == 6) {
                    $.fn.loadpage(6, true, false);
                }
            },
            error: function () {

            }
        });


        current.find("h3").html(isNullOrEmpty(currentShop.City) ? currentShop.Name : currentShop.City);
        current.find("h4").html(currentShop.Address /*+ "<br/>" + currentShop.PostalCode + " " + currentShop.City*/);

        if (currentShop.FrozenProducts === false) {
            current.find(".frozen-icon").hide();
        }
        else {
            current.find(".frozen-icon").show();
        }

        if (currentShop.ClothingProducts === false) {
            current.find(".cloth-icon").hide();
        }
        else {
            current.find(".cloth-icon").show();
        }

        if (currentShop.LuxuryProducts === false) {
            current.find(".jewel-icon").hide();
        }
        else {
            current.find(".jewel-icon").show();
        }

        switch (device.platform) {
            case "iOS":
                $("#gpslink").attr("href", "http://maps.apple.com?ll=" + currentShop.Latitude + "," + currentShop.Longitude + "&q=" + currentShop.Address + ", " + currentShop.City + "&daddr=" + currentShop.Address + ", " + currentShop.City);
                break;
            default:
                $("#gpslink").attr("href", "geo:" + currentShop.Latitude + "," + currentShop.Longitude + "?q=" + encodeURIComponent(currentShop.Address) + ", " + encodeURIComponent(currentShop.City) + "&daddr=" + currentShop.Address + ", " + currentShop.City);
        }
    };

    /**
    * Affichage de la localistaion d'un magasin
    */
    var displayShopLocalisation = function (current) {
        current.find("h3").html(isNullOrEmpty(currentShop.City) ? currentShop.Name : currentShop.City);
        current.find("h4").html(currentShop.Address /*+ "<br/>" + currentShop.PostalCode + " " + currentShop.City*/);

        var mapOptions = {
            center: new google.maps.LatLng(currentShop.Latitude, currentShop.Longitude),
            zoom: 13,
            mapTypeId: google.maps.MapTypeId.ROADMAP
        };

        var mapDiv = $("#map");
        var height = current.find(".footer").position().top - mapDiv.position().top - 60;
        mapDiv.css("height", height + "px");

        var map = new google.maps.Map(document.getElementById("map"),
               mapOptions);

        var marker = new google.maps.Marker({
            position: new google.maps.LatLng(currentShop.Latitude, currentShop.Longitude),
            map: map,
            icon: 'img/NOZ.png'
        });

    }

    /**
    * Affichage des arrivages d'un magasin
    **/
    var displayShopShipments = function (current) {

        var hide = false;
        if (getParameters().myShops.length > 5) {
            $(".addtofavorite").hide();
            hide = true;
        }

        if (isAlreadyFavorite(currentShop)) {
            $(".addtofavorite").hide();
            hide = true;
        }

        if (hide === false) {
            $(".addtofavorite").show();
        }

        current.find("h3").html(isNullOrEmpty(currentShop.City) ? currentShop.Name : currentShop.City);
        current.find("h4").html(currentShop.Address /*+ "<br/>" + currentShop.PostalCode + " " + currentShop.City*/);
        current.find(".openhours").text(currentShop.OpenText);

        if (currentShop.FrozenProducts === false) {
            current.find(".frozen-icon").hide();
        } else {
            current.find(".frozen-icon").show();
        }

        if (currentShop.ClothingProducts === false) {
            current.find(".cloth-icon").hide();
        } else {
            current.find(".cloth-icon").show();
        }

        if (currentShop.LuxuryProducts === false) {
            current.find(".jewel-icon").hide();
        } else {
            current.find(".jewel-icon").show();
        }

        var ul = current.find(".shipments");
        ul.empty();

        if (shipments === null) {
            ul.html("<li>Chargement...</li>");
            return;
        }

        if (shipments.length === 0) {
            ul.html("<li>Aucun arrivage</li>");
            return;
        }

        var grouped = {

        };

        $(shipments).each(function () {
            grouped[this.ProductCategory] = grouped[this.ProductCategory] || {
                mention: this.Mention,
                items: []
            };

            grouped[this.ProductCategory].items.push(this);
        });


        for (var category in grouped) {
            var catli = $("<li>" + category + "</li>");
            catli.addClass("list");

            var catul = $("<ul></ul>");
            catli.append(catul);

            $(grouped[category].items).each(function () {

                if (isNullOrEmpty(this.Designation)) {
                    return;
                }

                var prodLi = $("<li></li>");
                prodLi.append("<span class='designation'><span>" + this.Designation + "</span></span>");
                catul.append(prodLi);

                if ((this.Price > 0) && (!isNullOrEmpty(this.PriceText))) {
                    prodLi.append("<span class='unitprice'>(" + this.PriceText + ")</span>");
                }


                if (!isNullOrEmpty(this.UnitPrice)) {
                    prodLi.append("<div class='unitprice'>" + this.UnitPrice + "</div>");
                }

                var spanPrice = $("<span class='price'></span>");

                if (this.Price > 0) {
                    var intPrice = Math.floor(this.Price);
                    spanPrice.append("<span class='intprice'>" + intPrice + "</span>");
                    spanPrice.append("<sup>&euro;</sup>");

                    var decimalPrice = Math.floor(Math.round((this.Price - intPrice) * 100));
                    spanPrice.append("<span class='decimalPrice'>" + decimalPrice + "</span>");
                }
                else {
                    spanPrice.append("<span class='intprice'>" + this.PriceText + "</span>");
                }

                prodLi.append(spanPrice);

            });



            if (!isNullOrEmpty(grouped[category].mention)) {
                catli.append("<span class='mention'>" + grouped[category].mention + "</span>");
            }



            ul.append(catli);
        }

        current.find(".addtofavorite").data("shop", currentShop);

        var container = ul.closest(".winfound");

        var height = current.find(".footer").position().top - container.position().top - 60;

        container.css("height", height + "px");
        container.mCustomScrollbar("update");



    }

    /**
    * Affichage des 3 magasins les ^plus proches en bas de l'cran de menu des magasins
    **/
    var displayNearestShops = function (current) {

        $("input[name='searchbox']").empty();

        if (currentLatitude != undefined) {
            var nearest = shops.sort(function (a, b) {
                return calcDistance(a.Latitude, a.Longitude, currentLatitude, currentLongitude) - calcDistance(b.Latitude, b.Longitude, currentLatitude, currentLongitude);
            });

            nearest = nearest.slice(0, 3);

            displayFoundShops(nearest);
        }
    }

    var displayFavoriteShopList = function (current) {
        var parameters = getParameters();

        if (parameters.myShops.length === 0) {

            $.fn.loadpage(2, false);
            return;
        }

        var ul = current.find(".favorite-list");
        ul.empty();

        $(parameters.myShops).each(function () {
            var li = $("<li/>");

            var lot = $("<div class='lot'></div>");

            if (this.FrozenProducts === true) {
                lot.append("<img src='img/NOZ_ico-frais.png'/>");
            }

            if (this.ClothingProducts === true) {
                lot.append("<img src='img/NOZ_ico-vetements.png'/>");
            }

            if (this.LuxuryProducts === true) {
                lot.append("<img src='img/NOZ_ico-bijoux.png'/>");
            }

            li.append(lot);

            li.append("<h3>" + (isNullOrEmpty(this.City) ? this.Name : this.City) + "</h3>");
            //li.append("<h4>" + this.Address + "</h4>");
            //li.append("<p class='openhours'>" + this.OpenText + "</p>");



            var a = $('<a href="#" class="voirbtn">Voir les arrivages...</a>');
            li.append(a);
            a.data("shop", this);
            a.click(function (e) {
                e.preventDefault();

                var btn = this;
                $(this).text("chargement...");
                currentShop = $(this).data("shop");

                $.ajax({
                    crossDomain: true,
                    type: 'GET',
                    url: 'http://nozappliv2.azurewebsites.net/api/shipment?shopid=' + $(this).data("shop").Id,
                    dataType: 'json',
                    success: function (data) {
                        shipments = data;
                        $.fn.loadpage(6);
                        $(btn).text("Voir les arrivages...");

                    },
                    error: function () {

                    }
                });
            });

            ul.append(li);
        });

        //var container = ul.closest(".winfound");
        //var height = current.find(".footer").position().top - container.position().top - 45;

        //container.css("height", height + "px");

        //container.mCustomScrollbar("update");

    }

    /**
    * Affichage de la liste de tous les magasins
    **/
    var displayAllShops = function () {

        $("input[name='searchbox']").empty();

        var alpha = allshops.sort(function (a, b) {

            var aname = (isNullOrEmpty(a.City) ? a.Name : a.City).toLowerCase();
            var bname = (isNullOrEmpty(b.City) ? b.Name : b.City).toLowerCase();
            return aname < bname ? -1 : (aname > bname ? 1 : 0);
        });

        alpha = alpha.slice(0, alpha.length);

        displayFoundShops(alpha);


    }

    var displayAddShopList = function (current) {

        current.find("input").val("");

        current.find("input").css("width", "100%");

        var alpha = allshops.sort(function (a, b) {

            var aname = (isNullOrEmpty(a.City) ? a.Name : a.City).toLowerCase().replace(String.fromCharCode(233), 'e');
            var bname = (isNullOrEmpty(b.City) ? b.Name : b.City).toLowerCase().replace(String.fromCharCode(233), 'e');
            return aname < bname ? -1 : (aname > bname ? 1 : 0);
        });

        var firstLoad = alpha.slice(0, Math.min(999, alpha.length));

        displayShopsList(firstLoad);

    }

    var addFavoriteShop = function (shop) {

        var param = getParameters();

        if ((param.myShops.length >= 5) || isAlreadyFavorite(shop)) {
            return false;
        }

        param.myShops.push(shop);

        if (param.myShops.length >= 5) {
            $("#add").hide();
            $(".addtofavorite").hide();
        }

        setParameters(param);

        updatePush();

        return true;
    }

    var removeFavorite = function (shop) {
        var param = getParameters();

        for (var index = 0; index < param.myShops.length; index++) {

            if (param.myShops[index].Id === shop.Id) {
                param.myShops.remove(index);
                break;
            }
        }

        if (param.myShops.length < 5) {
            $("#add").show();
            $(".addtofavorite").show();
        }

        setParameters(param);

        updatePush();

        return true;
    }

    var isAlreadyFavorite = function (shop) {

        var param = getParameters();

        for (var index = 0; index < param.myShops.length; index++) {

            if (param.myShops[index].Id === shop.Id) {
                return true;
            }
        }

        return false;
    }

    function displayFoundShops(shops) {

        var ul = $("#magfound .results ul");
        ul.empty();

        if ((refreshing === true) || (!shops)) {
            var li = $("<li>Chargement...</li>");
            ul.append(li);
        }
        else if ((shops.length == 0)) {
            var li = $("<li>Impossible de charger les donn&eacute;es, veuillez v&eacute;rifier votre connection de donn&eacute;es</li>");
            ul.append(li);
        }
        else {
            var cli = $("<li>Chargement...</li>");
            ul.append(cli);

            $(shops).each(function () {
                var li = $("<li></li>");
                li.addClass("item");
                li.data("shop", this);

                var a = $("<h4>" + (isNullOrEmpty(this.City) ? this.Name : this.City) + "</h4>")
                var p = $("<p>" + this.Address + "</p>");

                li.append(a);
                li.append(p);

                li.on('click', function (e) {
                    e.preventDefault();
                    currentShop = $(this).data("shop");
                    $.fn.loadpage(8);
                });

                li.on('tap', function (e) {
                    e.preventDefault();
                    currentShop = $(this).data("shop");
                    $.fn.loadpage(8);
                });

                ul.append(li);
            });

            cli.remove();
        }

        var win = $("#magfound .results>div>div");
        var winpos = win.closest(".results").position().top;

        var height = win.closest(".page").find(".footer").position().top - winpos - 12;
        win.css("height", height + "px");

        ul.closest(".winfound").mCustomScrollbar("update");



        if (device.model == "iPhone2,1") {
            ul.closest(".winfound").parent().css("padding-top", "12px");
        }
    }

    function displayShopsList(shops, noempty) {

        var nbAdded = 0;
        var ul = $("#addmag .results ul");

        if (!noempty) {
            ul.empty();
        }

        if ((!shops) || (shops.length == 0)) {
            var li = $("<li>Chargement...</li>");
            ul.append(li);
            return;
        }
        if (false && $("#addmag input[name='searchbox']").val() == "") {
            var li = $("<li>Veuillez commencer &agrave; saisir une ville ou un code postal</li>");
            ul.append(li);
            var height = $(".addmag .window").closest(".page").find(".footer").position().top - $(".addmag .window").position().top - 95;
            $("#addmag .window").css("height", height + "px");
            $("#addmag .window").mCustomScrollbar("update");
            return;
        }
        else {
            $(shops).each(function (shopIndex) {
                var li = $("<li></li>");
                li.addClass("item");
                li.data("shop", this);

                var city = (isNullOrEmpty(this.City) ? this.Name : this.City) + (isNullOrEmpty(this.City2) ? "" : " - " + this.City2);
                if (city.length > 13) {
                    var spaceIndex = city.indexOf(" ");

                    while (spaceIndex >= 0 && spaceIndex < 8) {
                        city = city.replace(" ", "&nbsp;");
                        spaceIndex = city.indexOf(" ");
                    }

                    if (spaceIndex > 8) {
                        city = city.substr(0, spaceIndex);
                    }
                }

                var a = $("<h4 class='addtofavorite-item'>" + city + "</h4>")
                var p = $('<a href="#" class="addtofavorite"><img src="img/NOZ_add.png"></a>');

                if (((shopIndex > 0) && shops[shopIndex - 1].City == this.City) || (((shopIndex < shops.length - 1) && shops[shopIndex + 1].City == this.City))) {
                    a.append("<span class='discriminant'>" + this.Address + "</span>");
                    p.find("img").addClass("discriminated");
                }


                a.data("shop", this);
                p.data("shop", this);
                li.append(a);

                a.on("click", function (e) {
                    e.preventDefault();
                    var shop = $(this).data("shop");
                    if (addFavoriteShop(shop)) {

                        setTimeout(function () {
                            $.fn.loadpage(3);
                        }, 500);
                    }
                });

                li.append(p);


                if (!isAlreadyFavorite(this)) {
                    ul.append(li);
                }
            });

            setTimeout(function () {
                var height = $(".addmag .window").closest(".page").find(".footer").position().top - $(".addmag .window").position().top - 95;
                $("#addmag .window").css("height", height + "px");
                $("#addmag .window").mCustomScrollbar("update");
            }, 100);
        }
    }

    function calcDistance(latitude1, longitude1, latitude2, longitude2) {
        var radius = 6367;
        return (radius * 2 * Math.asin(Math.min(1, Math.sqrt((Math.pow(Math.sin((diffRadian(latitude1, latitude2)) / 2.0), 2.0) + Math.cos(toRadian(latitude1))
                * Math.cos(toRadian(latitude2)) * Math.pow(Math.sin((diffRadian(longitude1, longitude2)) / 2.0), 2.0))))));
    }

    function toRadian(val) {
        return val * (Math.PI / 180);
    }

    function diffRadian(val1, val2) {
        return toRadian(val2) - toRadian(val1);
    }

    function getOpeningHours(shop) {
        var days = ["Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday", "Sunday"];

        var prev = null;
        var start = 0;
        var results = [];

        for (var index = 0; index < days.length; index++) {
            var day = days[index];

            var current = {
                mopen: shop[day + "MorningOpening"],
                mclose: shop[day + "MorningClosing"],
                eopen: shop[day + "EveningOpening"],
                eclose: shop[day + "EveningClosing"]
            };

            if (prev == null || current.eclose != prev.eclose || current.eopen != prev.eopen || current.mclose != prev.mclose || current.mopen != prev.mopen) {
                if ((prev != null) && ((prev.eopen != "") || (prev.mopen != ""))) {
                    results.push({ from: start, to: index - 1, hours: prev });
                }

                start = index;
            }

            prev = current;

        }

        if ((prev != null) && ((prev.eopen != "") || (prev.mopen != ""))) {
            results.push({ from: start - 1, to: index - 1, hours: current });
        }

        return results;
    }

    function loadURL(url) {
        navigator.app.loadUrl(url, { openExternal: true });
        return false;
    }

    //setTimeout(function () {
    //    $().initializeApp();
    //}, 2000);




})(jQuery);

var getParameters = function () {
    var value = JSON.parse(window.localStorage.getItem("parameters"));

    if (value === null) {
        value = {
            myShops: [],
            notif: false,
            configured: false
        };

        setParameters(value);
    }

    return value;
}

var setParameters = function (parameters) {
    window.localStorage.setItem("parameters", JSON.stringify(parameters));
}

if (typeof String.prototype.startsWith != 'function') {
    String.prototype.startsWith = function (str) {
        return this.indexOf(str) == 0;
    };
}

var isNullOrEmpty = function (str) {
    return (str == null) || (str.length == 0);
};

Array.prototype.remove = function (from, to) {
    var rest = this.slice((to || from) + 1 || this.length);
    this.length = from < 0 ? this.length + from : from;
    return this.push.apply(this, rest);
};

var googleMapsInit = function () {

};

function onNotificationGCM(e) {
    $(".event.received").html('EVENT -> RECEIVED:' + e.event + '');

    switch (e.event) {
        case 'registered':
            if (e.regid.length > 0) {
                $(".event.received").append('<li>REGISTERED -> REGID:' + e.regid + "</li>");

                android_token = e.regid;

                var params = getParameters();
                var shopIds = "";

                $(params.myShops).each(function () {
                    shopIds += this.Id + ";";
                });

                if (params.notif) {

                    var data = JSON.stringify({
                        platform: 'android',
                        deviceToken: android_token,
                        shopIds: shopIds,
                        unsuscribed: false,
                        instId: 'android' + android_token
                    });

                    $(".event.received").html(data);

                    $.ajax({
                        url: 'http://nozappliv2.azurewebsites.net/api/notification',
                        type: 'POST',
                        crossDomain: true,
                        dataType: 'json',
                        contentType: 'application/json;charset=utf-8',
                        data: data
                    });
                }
                else if (params.ios_token) {
                    $.ajax({
                        url: 'http://nozappliv2.azurewebsites.net/api/notification',
                        type: 'POST',
                        crossDomain: true,
                        dataType: 'json',
                        contentType: 'application/json;charset=utf-8',
                        data: JSON.stringify({
                            platform: 'android',
                            deviceToken: android_token,
                            unsuscribed: true,
                            instId: 'android' + android_token
                        })
                    });
                }

            }
            break;

        case 'message':

            break;

        case 'error':
            $(".event.received").append('<div>ERROR -> MSG:' + e.msg + '</div>');
            break;

        default:

            break;
    }
}

